
body {
  color: #fff;
/*  background-image: url('/binding_dark.png');*/
  background-color: ghostwhite;
  font-family: 'Ubuntu', 'Droid Sans', sans-serif;
  font-size: 1em;
  padding: 0;
  margin: 0;
}

hr {
  border: 1px solid #333;
}

/* artifacts */
.date {
  color: #fff;
  text-shadow: 0 0 5px #000;
  border-radius: 50%;
  width: 55px;
  height: 55px;
  background:linear-gradient(to bottom, #ffc200, #f90);
  margin-right: 25px;
  float: left;
}

.date .date-month {
  text-align: center;
  line-height: 35px;
  font-weight: bold;
  font-size: 16px;
  font-family: 'Ubuntu';
}

.date .date-day {
  text-align: center;
  font-size: 13px;
  font-family: 'Ubuntu';
}

#container {
    color: black;
    width: 960px;
    margin-left: 210px;
    margin-top: 35px;
}

#container p {
  padding: 15px;
}

#container .post-body {
}

#container .post-body p {
  padding: 2px;
}

#container {
    .archive-list {
	padding: 15px;
    }
}

#container .post-list {
  padding: 15px;
}

#container .post-list ul {
  list-style-type: none;
  display: inline;
  padding: 0;
}

#container .post-list li {
  clear:both;
  margin-bottom: 25px;
}

#container .post-title {
	position: relative;
	background: #262626;
	border: 4px solid #ff8500;
  padding-top: 15px;
  padding-left: 25px;
  z-index: -9999;
}

#container .post-title:after, #container .post-title:before {
	right: 100%;
	border: solid transparent;
	content: " ";
	height: 0;
	width: 0;
	position: absolute;
	pointer-events: none;
}

#container .post-title:after {
	border-color: rgba(38, 38, 38, 0);
	border-right-color: #262626;
	border-width: 30px;
	top: 50%;
	margin-top: -30px;
}
#container .post-title:before {
	border-color: rgba(245, 136, 27, 0);
	border-right-color: #ff8500;
	border-width: 36px;
	top: 50%;
	margin-top: -36px;
}

#container .post-title h1 {
  margin: 0;
}

#container .wiki-body {

}

#container .wiki-body ul {
  list-style-type: square;
}

#container .wiki-body p {
  padding: 2px;
}

#container .search-body {
  padding: 15px;
}

#container .search-body p {
  padding: 2px;
}

#container .blog-form {
  width: 100%;
}

.blog-form-control {
  width: 100%;
  border: 3px solid #000;
  padding: 5px;
  font-family: 'Ubuntu', sans-serif;
  font-size: 14px;
}

.blog-form-control-medium {
  width: 45%;
}

.blog-form-control-textarea {
  height: 400px;
}

.btn {
  display: inline-block;
  margin: 5px;
  padding: 4px 12px;
  background: white;
  border: 1px solid rgba(0,0,0,0.15);
  border-radius: 5px;
  transition: all 0.3s ease-out;
  box-shadow:
    inset 0 1px 0 rgba(255,255,255,0.5),
    0 2px 2px rgba(0,0,0,0.3),
    0 0 4px 1px rgba(0,0,0,0.2);

  /* Font styles */
  text-decoration: none;
  text-shadow: 0 1px rgba(255,255,255,0.7);
  font-family: 'Ubuntu', sans-serif;
  color: black;
  cursor: pointer;
}

.btn:hover  {
  background-color: rgba(255,214,0,0.7);;
  text-decoration: none;
}

.blog-form-small {
  float: right;
  padding: 0;
}

.blog-form-small .blog-form-control-small {
  border: 1px solid #000;
  padding: 2px;
  font-family: 'Ubuntu', sans-serif;
  font-size: 12px;
}

.btn-small {
  display: inline-block;
  margin: 1px;
  padding: 1px 4px;
  background: lightgrey; 
  border: 1px solid rgba(0,0,0,0.15);
  border-radius: 1px;
  transition: all 0.3s ease-out;
  box-shadow:
    inset 0 1px 0 rgba(255,255,255,0.5),
    0 1px 1px rgba(0,0,0,0.3),
    0 0 1px 1px rgba(0,0,0,0.2);

  /* Font styles */
  text-decoration: none;
  text-shadow: 0 1px rgba(255,255,255,0.7);
  font-family: 'Ubuntu', sans-serif;
  font-size: 12px;
  cursor: pointer;
}

.blog-form-small .btn-small:hover  {
  background-color: rgba(255,214,0,0.7);;
}


#container a {
    font-weight: bold;

}

.clearfix {
    clear:both;
}

a {
  color: royalblue;
}
a:link {
  text-decoration: none; 
}
a:visited {
  text-decoration: none;
}
a:hover {
  text-decoration: underline;
}
a:active {
  text-decoration: none;
}

h1        { color: dodgerblue; font-family: 'Ubuntu', cursive; font-size: 38pt; }
h2        { color: dodgerblue; font-family: 'Ubuntu', cursive; font-size: 28pt; }
h3        { color: dodgerblue; font-family: 'Ubuntu', cursive; font-size: 18pt; }

h1, h2, h3 { 
  border-bottom: 1px solid lightgrey; 
  margin-bottom: 0;
  margin-top: 10px;
}

h4        { color: #000; }

.title h4 {
  font-style: italic;
  padding: 0px;
}

#header {
    clear:both;
    margin-top: 60px;
}


#header .logo img {
  border-radius: 10px;
}

#footer {
  color: #ffffff;
  text-shadow: 0px 0px 5px #ff8500;
  padding-top: 15px;
  width: 960px;
  margin-left: auto;
  margin-right: auto;
  font-size: 1em;
  clear: both;
}

#footer a {
  color: #fff;
}

#footer img {
  vertical-align: middle;
}

/* navbar */

#navbar {
  background-color: royalblue;
  color: white;
  text-shadow: 0px 0px 5px #000;
  font-size: 1em;
  height: 28px;
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  font-family: 'Ubuntu', sans-serif;
  z-index: 99999;
}

#navbar .links {
  text-indent: 1em;
  line-height: 30px;
  font-size: medium;
}

#navbar a {
  color: #fff;
}

#navbar img {
  vertical-align: middle;
}

#navbar-sub {
  background-color: royalblue;
  height: 100%;
  width: 200px;
  position: fixed;
  top:29px;
  left:0;
  color: #ffffff;
  text-shadow: 0px 0px 5px #000;
  font-size: 1em;
  margin-top: -17px;
  .links {
      margin-top: 15px;
  }
}

#navbar-sub ul {
  list-style-type: none;
  padding: 0;
  margin-left: 1em;
}

#navbar-sub ul li {

}

#navbar-sub .item-header {
  padding-left: 10px;
  margin-left: -10px;
  font-weight: bolder;
}

#navbar-sub a {
  color: #fff;
}

/* data table */
table { width: 100%; }
th { text-align: left; padding: 5px; background-color: skyblue}
td { padding:5px ;text-align: left; border: 0;}

blockquote {
    border-left: 2px dotted #888;
    padding-left: 5px;
    background: #d0f0ff;
}

.wmd-panel
{
    min-width: 500px;
}

.wmd-button-bar 
{
    width: 100%;
    background-color: Silver; 
}

.wmd-input 
{ 
    height: 500px;
    width: 100%;
    background-color: Gainsboro;
    border: 1px solid DarkGray;
}

.wmd-preview 
{ 
    background-color: #c0e0ff; 
}

.wmd-button-row 
{
    position: relative; 
    margin-left: 5px;
    margin-right: 5px;
    margin-bottom: 5px;
    margin-top: 10px;
    padding: 0px;  
    height: 20px;
}

.wmd-spacer
{
    width: 1px; 
    height: 20px; 
    margin-left: 14px;
    
    position: absolute;
    background-color: Silver;
    display: inline-block; 
    list-style: none;
}

.wmd-button {
    width: 20px;
    height: 20px;
    padding-left: 2px;
    padding-right: 3px;
    position: absolute;
    display: inline-block;
    list-style: none;
    cursor: pointer;
}

.wmd-button > span {
    background-image: url(/images/wmd-buttons.png);
    background-repeat: no-repeat;
    background-position: 0px 0px;
    width: 20px;
    height: 20px;
    display: inline-block;
}

.wmd-spacer1
{
    left: 50px;
}
.wmd-spacer2
{
    left: 175px;
}
.wmd-spacer3
{
    left: 300px;
}

.wmd-prompt-background
{
    background-color: Black;
}

.wmd-prompt-dialog
{
    border: 1px solid #999999;
    background-color: #F5F5F5;
    color: #000;
}

.wmd-prompt-dialog > div {
    font-size: 0.8em;
    font-family: arial, helvetica, sans-serif;
}


.wmd-prompt-dialog > form > input[type="text"] {
    border: 1px solid #999999;
    color: black;
}

.wmd-prompt-dialog > form > input[type="button"]{
    border: 1px solid #888888;
    font-family: trebuchet MS, helvetica, sans-serif;
    font-size: 0.8em;
    font-weight: bold;
}

/* installer */
#admin-body {
    span {
	font-weight: bolder;
	}
    form {
	label {
	    margin-top: 15px;
	}
	input {
	    width:375px;
	    display:block;
	    border: 1px solid #999;
	    height: 25px;
	    background-color: white;
	    font-family: 'Ubuntu', sans-serif;
	    color: black;
	    border-radius: 5px;
	    padding: 5px;
	}
	input[type="password"]:focus, 
	input[type="text"]:focus {
	    background-color: #333;
	    color: white;
	}
	input[type="submit"] {
	    width: 100px;
	}
    }
}
